==> oritech-fabric-1.21.1-0.18.0-sources.jar: rearth/oritech/block/entity/augmenter/PlayerAugments.java <==
package rearth.oritech.block.entity.augmenter;

import dev.architectury.registry.menu.MenuRegistry;
import rearth.oritech.Oritech;
import rearth.oritech.api.attachment.AttachmentApi;
import rearth.oritech.api.networking.NetworkManager;
import rearth.oritech.block.entity.augmenter.api.Augment;
import rearth.oritech.init.recipes.RecipeContent;

import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_1657;
import net.minecraft.class_1863;
import net.minecraft.class_2338;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_5455;
import net.minecraft.class_8710;

public class PlayerAugments {
    
    public static final Map<class_2960, Augment> allAugments = new HashMap<>();
    
    // this is called after recipe manager init / recipe reload
    public static void loadAllAugments(class_1863 manager) {
        allAugments.clear();
        manager.method_30027(RecipeContent.AUGMENT_DATA).forEach(recipe -> allAugments.put(recipe.comp_1932(), recipe.comp_1933().createAugment(recipe.comp_1932())));
    }
    
    public static void serverTickAugments(class_3222 player) {
        
        for (var augment : allAugments.values()) {
            if (augment.isEnabled(player)) {
                if (player.method_51469().method_8510() % augment.refreshInterval() == 0)
                    augment.refreshServer(player);
            }
        }
    }
    
    public static void receiveInstallTrigger(AugmentInstallTriggerPacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        var entity = player.method_37908().method_8321(packet.position);
        
        if (entity instanceof AugmentApplicationEntity modifierEntity) {
            var operation = PlayerAugments.AugmentApplicatorOperation.values()[packet.operationId];
            switch (operation) {
                case RESEARCH -> {
                    modifierEntity.researchAugment(packet.id, player.method_7337(), player);
                }
                case ADD -> {
                    modifierEntity.installAugmentToPlayer(packet.id, player);
                }
                case REMOVE -> {
                    modifierEntity.removeAugmentFromPlayer(packet.id, player);
                }
            }
        }
    }
    
    public static void receivePlayerLoadMachine(LoadPlayerAugmentsToMachinePacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        var entity = player.method_37908().method_8321(packet.position);
        
        if (entity instanceof AugmentApplicationEntity modifierEntity) {
            modifierEntity.loadResearchesFromPlayer(player);
        }
    }
    
    public static void receiveOpenAugmentScreen(OpenAugmentScreenPacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        var entity = player.method_37908().method_8321(packet.position);
        
        if (entity instanceof AugmentApplicationEntity modifierEntity && player instanceof class_3222 serverPlayer) {
            modifierEntity.screenInvOverride = true;
            MenuRegistry.openExtendedMenu(serverPlayer, modifierEntity);
        }
    }
    
    public static void receiveToggleAugment(AugmentPlayerTogglePacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        AugmentApplicationEntity.toggleAugmentForPlayer(packet.id, player);
    }
    
    public enum AugmentApplicatorOperation {
        RESEARCH, ADD, REMOVE, NONE, NEEDS_INIT
    }
    
    public record AugmentInstallTriggerPacket(class_2338 position, class_2960 id, int operationId) implements class_8710 {
        
        public static final class_8710.class_9154<AugmentInstallTriggerPacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_install"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
    
    public record LoadPlayerAugmentsToMachinePacket(class_2338 position) implements class_8710 {
        
        public static final class_8710.class_9154<LoadPlayerAugmentsToMachinePacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_loadtomachine"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
    
    public record OpenAugmentScreenPacket(class_2338 position) implements class_8710 {
        
        public static final class_8710.class_9154<OpenAugmentScreenPacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_openscreen"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
    
    public record AugmentPlayerTogglePacket(class_2960 id) implements class_8710 {
        
        public static final class_8710.class_9154<AugmentPlayerTogglePacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_toggle"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
}

==> oritech-fabric-1.21.1-0.19.6-sources.jar: rearth/oritech/block/entity/augmenter/PlayerAugments.java <==
package rearth.oritech.block.entity.augmenter;

import dev.architectury.registry.menu.MenuRegistry;
import rearth.oritech.Oritech;
import rearth.oritech.api.attachment.AttachmentApi;
import rearth.oritech.api.networking.NetworkManager;
import rearth.oritech.block.entity.augmenter.api.Augment;
import rearth.oritech.init.recipes.RecipeContent;

import java.util.HashMap;
import java.util.Map;
import net.minecraft.class_1657;
import net.minecraft.class_1863;
import net.minecraft.class_2338;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_5455;
import net.minecraft.class_8710;

public class PlayerAugments {
    
    public static final Map<class_2960, Augment> allAugments = new HashMap<>();
    
    // this is called after recipe manager init / recipe reload
    public static void loadAllAugments(class_1863 manager) {
        allAugments.clear();
        manager.method_30027(RecipeContent.AUGMENT_DATA).forEach(recipe -> allAugments.put(recipe.comp_1932(), recipe.comp_1933().createAugment(recipe.comp_1932())));
    }
    
    public static void serverTickAugments(class_3222 player) {
        
        for (var augment : allAugments.values()) {
            var data = AttachmentApi.getAttachmentValue(player, Augment.ACTIVE_AUGMENTS_DATA);
            if (augment.isEnabled(data)) {
                if (player.method_51469().method_8510() % augment.refreshInterval() == 0)
                    augment.refreshServer(player);
            }
        }
    }
    
    public static void receiveInstallTrigger(AugmentInstallTriggerPacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        var entity = player.method_37908().method_8321(packet.position);
        
        if (entity instanceof AugmentApplicationEntity modifierEntity) {
            var operation = PlayerAugments.AugmentApplicatorOperation.values()[packet.operationId];
            switch (operation) {
                case RESEARCH -> {
                    modifierEntity.researchAugment(packet.id, player.method_7337(), player);
                }
                case ADD -> {
                    modifierEntity.installAugmentToPlayer(packet.id, player);
                }
                case REMOVE -> {
                    modifierEntity.removeAugmentFromPlayer(packet.id, player);
                }
            }
        }
    }
    
    public static void receivePlayerLoadMachine(LoadPlayerAugmentsToMachinePacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        var entity = player.method_37908().method_8321(packet.position);
        
        if (entity instanceof AugmentApplicationEntity modifierEntity) {
            modifierEntity.loadResearchesFromPlayer(player);
        }
    }
    
    public static void receiveOpenAugmentScreen(OpenAugmentScreenPacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        var entity = player.method_37908().method_8321(packet.position);
        
        if (entity instanceof AugmentApplicationEntity modifierEntity && player instanceof class_3222 serverPlayer) {
            modifierEntity.screenInvOverride = true;
            MenuRegistry.openExtendedMenu(serverPlayer, modifierEntity);
        }
    }
    
    public static void receiveToggleAugment(AugmentPlayerTogglePacket packet, class_1657 player, class_5455 dynamicRegistryManager) {
        AugmentApplicationEntity.toggleAugmentForPlayer(packet.id, player);
    }
    
    public enum AugmentApplicatorOperation {
        RESEARCH, ADD, REMOVE, NONE, NEEDS_INIT
    }
    
    public record AugmentInstallTriggerPacket(class_2338 position, class_2960 id, int operationId) implements class_8710 {
        
        public static final class_8710.class_9154<AugmentInstallTriggerPacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_install"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
    
    public record LoadPlayerAugmentsToMachinePacket(class_2338 position) implements class_8710 {
        
        public static final class_8710.class_9154<LoadPlayerAugmentsToMachinePacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_loadtomachine"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
    
    public record OpenAugmentScreenPacket(class_2338 position) implements class_8710 {
        
        public static final class_8710.class_9154<OpenAugmentScreenPacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_openscreen"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
    
    public record AugmentPlayerTogglePacket(class_2960 id) implements class_8710 {
        
        public static final class_8710.class_9154<AugmentPlayerTogglePacket> PACKET_ID = new class_8710.class_9154<>(Oritech.id("aug_toggle"));
        
        @Override
        public class_9154<? extends class_8710> method_56479() {
            return PACKET_ID;
        }
    }
}
